pub struct PackageFamilyName { /* private fields */ }Expand description
A Package Family Name is an opaque string derived from only two parts of a package identity - name and publisher.
<Name>_<PublisherId>
For example, the Package Family Name of the Windows Photos app is
Microsoft.Windows.Photos_8wekyb3d8bbwe, where Microsoft.Windows.Photos is the name and
8wekyb3d8bbwe is the publisher ID for Microsoft.
Package Family Name is often referred to as a ‘version-less Package Full Name’.
Implementations
Sourceimpl PackageFamilyName
impl PackageFamilyName
Sourcepub fn new(package_name: &str, publisher: &str) -> PackageFamilyName
pub fn new(package_name: &str, publisher: &str) -> PackageFamilyName
Creates a new Package Family Name from a package name and an identity publisher.
This is equivalent to the Windows function PackageNameAndPublisherIdFromFamilyName.
Examples
let package_family_name = PackageFamilyName::new(
"Microsoft.PowerShell",
"CN=Microsoft Corporation, O=Microsoft Corporation, L=Redmond, S=Washington, C=US"
);
assert_eq!(package_family_name.to_string(), "Microsoft.PowerShell_8wekyb3d8bbwe");Sourcepub fn package_name(&self) -> &str
pub fn package_name(&self) -> &str
Returns the package name as a string slice.
Examples
let package_family_name = PackageFamilyName::new(
"Microsoft.PowerShell",
"CN=Microsoft Corporation, O=Microsoft Corporation, L=Redmond, S=Washington, C=US"
);
assert_eq!(package_family_name.package_name(), "Microsoft.PowerShell");Sourcepub const fn publisher_id(&self) -> &PublisherId
pub const fn publisher_id(&self) -> &PublisherId
Returns a reference to the Publisher Id.
Examples
let package_family_name = PackageFamilyName::new(
"Microsoft.PowerShell",
"CN=Microsoft Corporation, O=Microsoft Corporation, L=Redmond, S=Washington, C=US"
);
assert_eq!(package_family_name.publisher_id().as_str(), "8wekyb3d8bbwe");Trait Implementations
Sourceimpl Clone for PackageFamilyName
impl Clone for PackageFamilyName
Sourcefn clone(&self) -> PackageFamilyName
fn clone(&self) -> PackageFamilyName
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PackageFamilyName
impl Debug for PackageFamilyName
Sourceimpl Default for PackageFamilyName
impl Default for PackageFamilyName
Sourcefn default() -> PackageFamilyName
fn default() -> PackageFamilyName
Sourceimpl Display for PackageFamilyName
impl Display for PackageFamilyName
impl Eq for PackageFamilyName
Sourceimpl FromStr for PackageFamilyName
impl FromStr for PackageFamilyName
Sourcetype Err = PackageFamilyNameError
type Err = PackageFamilyNameError
Sourcefn from_str(
s: &str,
) -> Result<PackageFamilyName, <PackageFamilyName as FromStr>::Err>
fn from_str( s: &str, ) -> Result<PackageFamilyName, <PackageFamilyName as FromStr>::Err>
s to return a value of this type. Read moreSourceimpl Hash for PackageFamilyName
impl Hash for PackageFamilyName
Sourceimpl Ord for PackageFamilyName
impl Ord for PackageFamilyName
Sourcefn cmp(&self, other: &PackageFamilyName) -> Ordering
fn cmp(&self, other: &PackageFamilyName) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for PackageFamilyName
impl PartialEq for PackageFamilyName
Sourcefn eq(&self, other: &PackageFamilyName) -> bool
fn eq(&self, other: &PackageFamilyName) -> bool
Tests for self and other values to be equal, and is used by ==.
Package Family Name is compared case-insensitively.
Examples
let pfn_1 = PackageFamilyName::new("PowerShell", "CN=, O=, L=, S=, C=");
let pfn_2 = PackageFamilyName::new("powershell", "CN=, O=, L=, S=, C=");
assert_eq!(pfn_1, pfn_2);Sourceimpl PartialOrd for PackageFamilyName
impl PartialOrd for PackageFamilyName