VersionManifest

Struct VersionManifest 

pub struct VersionManifest {
    pub package_identifier: PackageIdentifier,
    pub package_version: PackageVersion,
    /* private fields */
}

Fields

package_identifier: PackageIdentifier

The unique identifier for a given package.

This value is generally in the form of Publisher.Package. It is case-sensitive, and this value must match the folder structure under the partition directory in GitHub.

package_version: PackageVersion

The version of the package.

It is related to the specific release this manifests targets. In some cases you will see a perfectly formed semantic version number, and in other cases you might see something different. These may be date driven, or they might have other characters with some package specific meaning for example.

The Windows Package Manager client uses this version to determine if an upgrade for a package is available. In some cases, packages may be released with a marketing driven version, and that causes trouble with the winget upgrade command.

The current best practice is to use the value reported in Add / Remove Programs when this version of the package is installed. In some cases, packages do not report a version resulting in an upgrade loop or other unwanted behavior.

Implementations

Source

impl VersionManifest

pub fn new( package_identifier: PackageIdentifier, package_version: PackageVersion, default_locale: LanguageTag, ) -> Self

Creates a new VersionManifest from a PackageIdentifier, a PackageVersion, and a default locale tag.

pub const fn default_locale(&self) -> &LanguageTag

Returns the default locale.

pub const fn manifest_version(&self) -> ManifestVersion

Returns the manifest version.

pub fn update(&mut self, package_version: &PackageVersion)