GenericManifest

Struct GenericManifest 

pub struct GenericManifest {
    pub type: ManifestType,
}
A manifest where the only field is the type of the manifest itself.

This is useful for deserializing once into this type to determine which manifest to properly deserialize into.

Fields

type: ManifestType